pub struct AbiSerializer { /* private fields */ }Available on crate feature
abi only.Expand description
Abi format serializer for serde
Implementations
Sourceimpl AbiSerializer
impl AbiSerializer
pub fn start_tuple(&mut self, variable_length: bool) -> Result<(), AbiSerError>
pub fn end_tuple(&mut self) -> Result<(), AbiSerError>
Sourcepub fn encode_bytes(&mut self, bytes: Vec<u8>) -> Result<(), AbiSerError>
pub fn encode_bytes(&mut self, bytes: Vec<u8>) -> Result<(), AbiSerError>
of length k (which is assumed to be of type uint256): enc(X) = enc(k) pad_right(X), i.e. the number of bytes i s encoded as a uint256 followed by the actual value of X as a byte sequence, followed by the minimum number of zero-bytes such that len(enc(X)) is a multiple of 32.
Sourcepub fn encode_usize(&mut self, value: usize) -> Result<(), AbiSerError>
pub fn encode_usize(&mut self, value: usize) -> Result<(), AbiSerError>
Encode rust usize to contract unit
pub fn encode_bytes32(&mut self, bytes: &[u8]) -> Result<(), AbiSerError>
Sourcepub fn append_byte(&mut self, byte: u8) -> Result<(), AbiSerError>
pub fn append_byte(&mut self, byte: u8) -> Result<(), AbiSerError>
Append byte to openned group bytes